==> kibana-2025.2.1+9629a4692.tgz: kibana/CHANGELOG.md <==
# Release notes

## 2025.2.0-21

## 2025.2.0

- Upgrade to the latest v8.18.1, in sync with Elasticsearch

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

### Bug Fixes

- Fix retry logic to index creation script.
  Prevent creation of duplicate indexes.

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Drop usage of fsGroup inside container
- 0.1.3 Enable TLS with Elasticsearch
- 0.1.4 Enable TLS for Kibana ingress path
- 0.1.5 Use full image ref for docker official images
- 0.1.6 Remove Kibana indices before pod start up
- 0.1.7 Helm 3 - Fix Job labels
- 0.1.8 Update htk requirements
- 0.1.9 Revert removing Kibana indices before pod start up
- 0.1.10 Update image defaults
- 0.1.11 Added OCI registry authentication
- 0.1.12 Added feedback http_code 200 for kibana indexes
- 0.1.13 Update Kibana to 8.9.0
- 0.1.14 Add 2023.1 Ubuntu Focal overrides
- 0.1.15 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.16 Add 2024.1 Ubuntu Jammy overrides
- 0.1.17 Update script to use data views replacing deprecated api
- 0.1.18 Add retry logic to create_kibana_index_patterns.sh
- 0.1.19 Add 2024.2 overrides
- 0.1.20 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> kibana-2025.2.6+134065b79.tgz: kibana/CHANGELOG.md <==
# Release notes

## 2025.2.0-54

- Upgrade to v8.19.9, in sync with Elasticsearch

### New Features

- Update default ingress classes and annotations for charts to make them implementation
  agnostic. They used to be nginx specific because we always used ingress-nginx as the most
  common choice. Ingress-nginx is deprecated and will become unmaintained in Feb/2026.
  
  Now for all test jobs we use HAProxy Ingress as the default implementation. However any
  other implementation can be used as far as it suppports annotations similar to
  'nginx.ingress.kubernetes.io/rewrite-target' or 'haproxy.org/path-rewrite' which are
  used in many OpenStack-Helm charts.

## 2025.2.0

- Upgrade to the latest v8.18.1, in sync with Elasticsearch

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

### Bug Fixes

- Fix retry logic to index creation script.
  Prevent creation of duplicate indexes.

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency version to ">= 0.1.0"
- 0.1.2 Drop usage of fsGroup inside container
- 0.1.3 Enable TLS with Elasticsearch
- 0.1.4 Enable TLS for Kibana ingress path
- 0.1.5 Use full image ref for docker official images
- 0.1.6 Remove Kibana indices before pod start up
- 0.1.7 Helm 3 - Fix Job labels
- 0.1.8 Update htk requirements
- 0.1.9 Revert removing Kibana indices before pod start up
- 0.1.10 Update image defaults
- 0.1.11 Added OCI registry authentication
- 0.1.12 Added feedback http_code 200 for kibana indexes
- 0.1.13 Update Kibana to 8.9.0
- 0.1.14 Add 2023.1 Ubuntu Focal overrides
- 0.1.15 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.16 Add 2024.1 Ubuntu Jammy overrides
- 0.1.17 Update script to use data views replacing deprecated api
- 0.1.18 Add retry logic to create_kibana_index_patterns.sh
- 0.1.19 Add 2024.2 overrides
- 0.1.20 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
